==> rgug4130a_1.10.0.tar.gz: rgug4130a/man/rgug4130aENZYME.Rd <==
\name{rgug4130aENZYME}
\alias{rgug4130aENZYME}
\title{Map Between Manufacturer IDs and Enzyme Commission (EC) Numbers}
\description{ 
  rgug4130aENZYME is an R environment that provides mappings between
  manufacturer ids and EC numbers. 
}
\details{
  Each manufacturer id maps to a named vector containing the EC number that
  corresponds to the enzyme produced by that gene. The name corresponds
  to the manufacturer id. If this information is unknown, the vector
  will contain an \code{NA}.
  
  Enzyme Commission numbers are assigned by the Nomenclature Committee
  of the International Union of Biochemistry and Molecular Biology
  \url{http://www.chem.qmw.ac.uk/iubmb/enzyme/} to allow enzymes to be
  identified. 
  
  An Enzyme Commission number is of the format EC x.y.z.w, where x, y, z,
  and w are numeric numbers. In rgug4130aENZYME2PROBE, EC is dropped from the
  Enzyme Commission numbers.

  Enzyme Commission numbers have corresponding names that describe the
  functions of enzymes in such a way that EC x is a more general
  description than EC x.y that in turn is a more general description than
  EC x.y.z. The top level EC numbers and names are listed below:

  EC 1 oxidoreductases
  
  EC 2 transferases

  EC 3 hydrolases

  EC 4 lyases
  
  EC 5 isomerases
  
  EC 6 ligases
  
  The EC name for a given EC number can be viewed at
  \url{http://www.chem.qmul.ac.uk/iupac/jcbn/index.html#6} 
  
  Mappings between probe ids and enzyme ids were obtained using files
  provided by:

  KEGG:\url{http://gopher5/compbio/annotationSourceData/kegg/pathways}. Built: Release 36.0, October 1, 2005

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue Oct  4 23:15:10 2005
  
  Package built Tue Oct  4 23:27:48 2005
}
\references{
\url{ftp://ftp.genome.ad.jp/pub/kegg/pathways}
}
\examples{
        # Convert to a list
        xx <- as.list(rgug4130aENZYME)
        # Remove probe ids that do not map to any enzyme EC number
        xx <- xx[!is.na(xx)]
        if(length(xx) > 0){
        # Gets the enzyme commission numbers for the first five
        #probes
        xx[1:5]
        # Get the first one
        xx[[1]]
}
}
\keyword{datasets}

==> rgug4130a_1.12.0.tar.gz: rgug4130a/man/rgug4130aENZYME.Rd <==
\name{rgug4130aENZYME}
\alias{rgug4130aENZYME}
\title{Map Between Manufacturer IDs and Enzyme Commission (EC) Numbers}
\description{ 
  rgug4130aENZYME is an R environment that provides mappings between
  manufacturer ids and EC numbers. 
}
\details{
  Each manufacturer id maps to a named vector containing the EC number that
  corresponds to the enzyme produced by that gene. The name corresponds
  to the manufacturer id. If this information is unknown, the vector
  will contain an \code{NA}.
  
  Enzyme Commission numbers are assigned by the Nomenclature Committee
  of the International Union of Biochemistry and Molecular Biology
  \url{http://www.chem.qmw.ac.uk/iubmb/enzyme/} to allow enzymes to be
  identified. 
  
  An Enzyme Commission number is of the format EC x.y.z.w, where x, y, z,
  and w are numeric numbers. In rgug4130aENZYME2PROBE, EC is dropped from the
  Enzyme Commission numbers.

  Enzyme Commission numbers have corresponding names that describe the
  functions of enzymes in such a way that EC x is a more general
  description than EC x.y that in turn is a more general description than
  EC x.y.z. The top level EC numbers and names are listed below:

  EC 1 oxidoreductases
  
  EC 2 transferases

  EC 3 hydrolases

  EC 4 lyases
  
  EC 5 isomerases
  
  EC 6 ligases
  
  The EC name for a given EC number can be viewed at
  \url{http://www.chem.qmul.ac.uk/iupac/jcbn/index.html#6} 
  
  Mappings between probe ids and enzyme ids were obtained using files
  provided by:

  KEGG:\url{ftp://ftp.genome.ad.jp/pub/kegg/tarfiles/pathway.tar.gz}. Built: Release 37.0, January 4, 2006

  Entrez Gene:\url{ftp://ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Sun Mar 26 03:30:23 2006
  
  Package built Sun Mar 26 03:42:24 2006
}
\references{
\url{ftp://ftp.genome.ad.jp/pub/kegg/pathways}
}
\examples{
        # Convert to a list
        xx <- as.list(rgug4130aENZYME)
        # Remove probe ids that do not map to any enzyme EC number
        xx <- xx[!is.na(xx)]
        if(length(xx) > 0){
        # Gets the enzyme commission numbers for the first five
        #probes
        xx[1:5]
        # Get the first one
        xx[[1]]
}
}
\keyword{datasets}
